# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payment_intents.post import CreatePaymentIntent
from circle.paths.v1_payment_intents_id_expire.post import ExpirePaymentIntent
from circle.paths.v1_payment_intents_id.get import GetPaymentIntent
from circle.paths.v1_payment_intents.get import ListPaymentIntents
from circle.paths.v1_payment_intents_id_refund.post import RefundPaymentIntent


class CryptoPaymentIntentsApi(
    CreatePaymentIntent,
    ExpirePaymentIntent,
    GetPaymentIntent,
    ListPaymentIntents,
    RefundPaymentIntent,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
