# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_checkout_sessions.post import CreateCheckoutSession
from circle.paths.v1_checkout_sessions_id_extend.post import ExtendCheckoutSession
from circle.paths.v1_checkout_sessions_id.get import GetCheckoutSession
from circle.paths.v1_checkout_sessions.get import ListCheckoutSessions


class CheckoutSessionsApi(
    CreateCheckoutSession,
    ExtendCheckoutSession,
    GetCheckoutSession,
    ListCheckoutSessions,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
