# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CardCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expMonth",
            "metadata",
            "billingDetails",
            "expYear",
            "idempotencyKey",
            "encryptedData",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
            encryptedData = schemas.StrSchema
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
        
            @staticmethod
            def expMonth() -> typing.Type['CardExpMonth']:
                return CardExpMonth
        
            @staticmethod
            def expYear() -> typing.Type['CardExpYear']:
                return CardExpYear
        
            @staticmethod
            def metadata() -> typing.Type['MetadataCardAndAch']:
                return MetadataCardAndAch
            keyId = schemas.UUIDSchema
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "encryptedData": encryptedData,
                "billingDetails": billingDetails,
                "expMonth": expMonth,
                "expYear": expYear,
                "metadata": metadata,
                "keyId": keyId,
            }
    
    expMonth: 'CardExpMonth'
    metadata: 'MetadataCardAndAch'
    billingDetails: 'BillingDetails'
    expYear: 'CardExpYear'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    encryptedData: MetaOapg.properties.encryptedData
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["encryptedData"]) -> MetaOapg.properties.encryptedData: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataCardAndAch': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["keyId"]) -> MetaOapg.properties.keyId: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "encryptedData", "billingDetails", "expMonth", "expYear", "metadata", "keyId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["encryptedData"]) -> MetaOapg.properties.encryptedData: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataCardAndAch': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["keyId"]) -> typing.Union[MetaOapg.properties.keyId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "encryptedData", "billingDetails", "expMonth", "expYear", "metadata", "keyId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expMonth: 'CardExpMonth',
        metadata: 'MetadataCardAndAch',
        billingDetails: 'BillingDetails',
        expYear: 'CardExpYear',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        encryptedData: typing.Union[MetaOapg.properties.encryptedData, str, ],
        keyId: typing.Union[MetaOapg.properties.keyId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CardCreationRequest':
        return super().__new__(
            cls,
            *_args,
            expMonth=expMonth,
            metadata=metadata,
            billingDetails=billingDetails,
            expYear=expYear,
            idempotencyKey=idempotencyKey,
            encryptedData=encryptedData,
            keyId=keyId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.billing_details import BillingDetails
from circle.model.card_exp_month import CardExpMonth
from circle.model.card_exp_year import CardExpYear
from circle.model.metadata_card_and_ach import MetadataCardAndAch
