from circle.paths.v1_notifications_subscriptions.get import ApiForget
from circle.paths.v1_notifications_subscriptions.post import ApiForpost


class V1NotificationsSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass
