# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_wallets.post import CreateWallet
from circle.paths.v1_wallets_wallet_id_addresses.post import GenerateAddress
from circle.paths.v1_wallets_wallet_id.get import GetWallet
from circle.paths.v1_wallets_wallet_id_addresses.get import ListAddresses
from circle.paths.v1_wallets.get import ListWallets


class WalletsApi(
    CreateWallet,
    GenerateAddress,
    GetWallet,
    ListAddresses,
    ListWallets,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
