# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ChargebackCategories(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated category of the chargeback status codes based on the chargeback status code.
    """
    
    @schemas.classproperty
    def CANCELED_RECURRING_PAYMENT(cls):
        return cls("Canceled Recurring Payment")
    
    @schemas.classproperty
    def CUSTOMER_DISPUTE(cls):
        return cls("Customer Dispute")
    
    @schemas.classproperty
    def FRAUDULENT(cls):
        return cls("Fraudulent")
    
    @schemas.classproperty
    def GENERAL(cls):
        return cls("General")
    
    @schemas.classproperty
    def PROCESSING_ERROR(cls):
        return cls("Processing Error")
    
    @schemas.classproperty
    def NOT_DEFINED(cls):
        return cls("Not Defined")
