from circle.paths.v1_address_book_recipients.get import ApiForget
from circle.paths.v1_address_book_recipients.post import ApiForpost


class V1AddressBookRecipients(
    ApiForget,
    ApiForpost,
):
    pass
