# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Eci(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    ECI (electronic commerce indicator) value returned by Directory Servers (namely Visa, MasterCard, JCB, and American Express) indicating the outcome of authentication attempted on transactions enforced by 3DS.
    """


    class MetaOapg:
        enum_value_to_name = {
            "00": "POSITIVE_00",
            "01": "POSITIVE_01",
            "02": "POSITIVE_02",
            "05": "POSITIVE_05",
            "06": "POSITIVE_06",
            "07": "POSITIVE_07",
        }
    
    @schemas.classproperty
    def POSITIVE_00(cls):
        return cls("00")
    
    @schemas.classproperty
    def POSITIVE_01(cls):
        return cls("01")
    
    @schemas.classproperty
    def POSITIVE_02(cls):
        return cls("02")
    
    @schemas.classproperty
    def POSITIVE_05(cls):
        return cls("05")
    
    @schemas.classproperty
    def POSITIVE_06(cls):
        return cls("06")
    
    @schemas.classproperty
    def POSITIVE_07(cls):
        return cls("07")
