from circle.paths.v1_business_account_banks_wires.get import ApiForget
from circle.paths.v1_business_account_banks_wires.post import ApiForpost


class V1BusinessAccountBanksWires(
    ApiForget,
    ApiForpost,
):
    pass
