# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_payouts.post import CreateBusinessPayout
from circle.paths.v1_payouts.post import CreatePayout
from circle.paths.v1_business_account_payouts_id.get import GetBusinessPayout
from circle.paths.v1_payouts_id.get import GetPayout
from circle.paths.v1_business_account_payouts.get import ListBusinessPayouts
from circle.paths.v1_payouts.get import ListPayouts


class PayoutsApi(
    CreateBusinessPayout,
    CreatePayout,
    GetBusinessPayout,
    GetPayout,
    ListBusinessPayouts,
    ListPayouts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
