# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_banks_wires.post import CreateBusinessWireAccount
from circle.paths.v1_business_account_banks_wires_id.get import GetBusinessWireAccount
from circle.paths.v1_business_account_banks_wires_id_instructions.get import GetBusinessWireAccountInstructions
from circle.paths.v1_business_account_banks_wires.get import ListBusinessWireAccounts


class WiresApi(
    CreateBusinessWireAccount,
    GetBusinessWireAccount,
    GetBusinessWireAccountInstructions,
    ListBusinessWireAccounts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
