# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentIntentCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "settlementCurrency",
            "idempotencyKey",
            "paymentMethods",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
            
            
            class settlementCurrency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "USD": "USD",
                        "BTC": "BTC",
                        "ETH": "ETH",
                    }
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class paymentMethods(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentMethodBlockchain']:
                        return PaymentMethodBlockchain
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentMethodBlockchain'], typing.List['PaymentMethodBlockchain']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentMethods':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentMethodBlockchain':
                    return super().__getitem__(i)
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "amount": amount,
                "settlementCurrency": settlementCurrency,
                "paymentMethods": paymentMethods,
                "merchantWalletId": merchantWalletId,
            }
    
    amount: 'CryptoPaymentsMoney'
    settlementCurrency: MetaOapg.properties.settlementCurrency
    idempotencyKey: MetaOapg.properties.idempotencyKey
    paymentMethods: MetaOapg.properties.paymentMethods
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "amount", "settlementCurrency", "paymentMethods", "merchantWalletId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "amount", "settlementCurrency", "paymentMethods", "merchantWalletId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'CryptoPaymentsMoney',
        settlementCurrency: typing.Union[MetaOapg.properties.settlementCurrency, str, ],
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        paymentMethods: typing.Union[MetaOapg.properties.paymentMethods, list, tuple, ],
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentIntentCreationRequest':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            settlementCurrency=settlementCurrency,
            idempotencyKey=idempotencyKey,
            paymentMethods=paymentMethods,
            merchantWalletId=merchantWalletId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payments_money import CryptoPaymentsMoney
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_method_blockchain import PaymentMethodBlockchain
