from circle.paths.v1_business_account_payouts.get import ApiForget
from circle.paths.v1_business_account_payouts.post import ApiForpost


class V1BusinessAccountPayouts(
    ApiForget,
    ApiForpost,
):
    pass
