# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_cards.post import CreateCard
from circle.paths.v1_cards_id.get import GetCard
from circle.paths.v1_cards.get import ListCards
from circle.paths.v1_cards_id.put import UpdateCard


class CardsApi(
    CreateCard,
    GetCard,
    ListCards,
    UpdateCard,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
