# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.ping.get import Ping


class HealthApi(
    Ping,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
