# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ContinuousPaymentIntent(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "settlementCurrency",
            "paymentMethods",
            "currency",
            "type",
        }
        
        class properties:
            
            
            class currency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class settlementCurrency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class paymentMethods(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentMethodBlockchain']:
                        return PaymentMethodBlockchain
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentMethodBlockchain'], typing.List['PaymentMethodBlockchain']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentMethods':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentMethodBlockchain':
                    return super().__getitem__(i)
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CONTINUOUS(cls):
                    return cls("continuous")
            id = schemas.UUIDSchema
        
            @staticmethod
            def amountPaid() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
        
            @staticmethod
            def amountRefunded() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
            
            
            class fees(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentIntentFees']:
                        return PaymentIntentFees
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentIntentFees'], typing.List['PaymentIntentFees']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fees':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentIntentFees':
                    return super().__getitem__(i)
            
            
            class timeline(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Timeline']:
                        return Timeline
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Timeline'], typing.List['Timeline']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'timeline':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Timeline':
                    return super().__getitem__(i)
            updateDate = schemas.StrSchema
            createDate = schemas.StrSchema
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            __annotations__ = {
                "currency": currency,
                "settlementCurrency": settlementCurrency,
                "paymentMethods": paymentMethods,
                "type": type,
                "id": id,
                "amountPaid": amountPaid,
                "amountRefunded": amountRefunded,
                "fees": fees,
                "timeline": timeline,
                "updateDate": updateDate,
                "createDate": createDate,
                "merchantWalletId": merchantWalletId,
            }
    
    settlementCurrency: MetaOapg.properties.settlementCurrency
    paymentMethods: MetaOapg.properties.paymentMethods
    currency: MetaOapg.properties.currency
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountPaid"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountRefunded"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> MetaOapg.properties.fees: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timeline"]) -> MetaOapg.properties.timeline: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["currency", "settlementCurrency", "paymentMethods", "type", "id", "amountPaid", "amountRefunded", "fees", "timeline", "updateDate", "createDate", "merchantWalletId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountPaid"]) -> typing.Union['CryptoPaymentsMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountRefunded"]) -> typing.Union['CryptoPaymentsMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union[MetaOapg.properties.fees, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timeline"]) -> typing.Union[MetaOapg.properties.timeline, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["currency", "settlementCurrency", "paymentMethods", "type", "id", "amountPaid", "amountRefunded", "fees", "timeline", "updateDate", "createDate", "merchantWalletId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        settlementCurrency: typing.Union[MetaOapg.properties.settlementCurrency, str, ],
        paymentMethods: typing.Union[MetaOapg.properties.paymentMethods, list, tuple, ],
        currency: typing.Union[MetaOapg.properties.currency, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        amountPaid: typing.Union['CryptoPaymentsMoney', schemas.Unset] = schemas.unset,
        amountRefunded: typing.Union['CryptoPaymentsMoney', schemas.Unset] = schemas.unset,
        fees: typing.Union[MetaOapg.properties.fees, list, tuple, schemas.Unset] = schemas.unset,
        timeline: typing.Union[MetaOapg.properties.timeline, list, tuple, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ContinuousPaymentIntent':
        return super().__new__(
            cls,
            *_args,
            settlementCurrency=settlementCurrency,
            paymentMethods=paymentMethods,
            currency=currency,
            type=type,
            id=id,
            amountPaid=amountPaid,
            amountRefunded=amountRefunded,
            fees=fees,
            timeline=timeline,
            updateDate=updateDate,
            createDate=createDate,
            merchantWalletId=merchantWalletId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payments_money import CryptoPaymentsMoney
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_intent_fees import PaymentIntentFees
from circle.model.payment_method_blockchain import PaymentMethodBlockchain
from circle.model.timeline import Timeline
