# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_transfers.post import CreateBusinessTransfer
from circle.paths.v1_transfers.post import CreateTransfer
from circle.paths.v1_business_account_transfers_id.get import GetBusinessTransfer
from circle.paths.v1_transfers_id.get import GetTransfer
from circle.paths.v1_business_account_transfers.get import ListBusinessTransfers
from circle.paths.v1_transfers.get import ListTransfers


class TransfersApi(
    CreateBusinessTransfer,
    CreateTransfer,
    GetBusinessTransfer,
    GetTransfer,
    ListBusinessTransfers,
    ListTransfers,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
