# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_mocks_cards_chargebacks.post import CreateMockChargeback
from circle.paths.v1_chargebacks_id.get import GetChargeback
from circle.paths.v1_chargebacks.get import ListChargebacks


class ChargebacksApi(
    CreateMockChargeback,
    GetChargeback,
    ListChargebacks,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
