# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_banks_cbit.post import CreateBusinessCbitAccount
from circle.paths.v1_business_account_banks_cbit_id.get import GetBusinessCbitAccount
from circle.paths.v1_business_account_banks_cbit_id_instructions.get import GetBusinessCbitAccountInstructions
from circle.paths.v1_business_account_banks_cbit.get import ListBusinessCbitAccounts


class CBITApi(
    CreateBusinessCbitAccount,
    GetBusinessCbitAccount,
    GetBusinessCbitAccountInstructions,
    ListBusinessCbitAccounts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
