# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_address_book_recipients.post import CreateAddressBookRecipient
from circle.paths.v1_address_book_recipients_id.delete import DeleteAddressBookRecipient
from circle.paths.v1_address_book_recipients_id.get import GetAddressBookRecipient
from circle.paths.v1_address_book_recipients.get import ListAddressBookRecipients
from circle.paths.v1_address_book_recipients_id.patch import ModifyAddressBookRecipient


class CryptoAddressBookApi(
    CreateAddressBookRecipient,
    DeleteAddressBookRecipient,
    GetAddressBookRecipient,
    ListAddressBookRecipients,
    ModifyAddressBookRecipient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
