from circle.paths.v1_business_account_wallets_addresses_recipient.get import ApiForget
from circle.paths.v1_business_account_wallets_addresses_recipient.post import ApiForpost


class V1BusinessAccountWalletsAddressesRecipient(
    ApiForget,
    ApiForpost,
):
    pass
