# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payments_id_cancel.post import CancelPayment
from circle.paths.v1_payments_id_capture.post import CapturePayment
from circle.paths.v1_mocks_payments_wire.post import CreateMockWirePayment
from circle.paths.v1_payments.post import CreatePayment
from circle.paths.v1_payments_id.get import GetPayment
from circle.paths.v1_payments.get import ListPayments
from circle.paths.v1_payments_id_refund.post import RefundPayment


class PaymentsApi(
    CancelPayment,
    CapturePayment,
    CreateMockWirePayment,
    CreatePayment,
    GetPayment,
    ListPayments,
    RefundPayment,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
