from circle.paths.v1_wallets_wallet_id_addresses.get import ApiForget
from circle.paths.v1_wallets_wallet_id_addresses.post import ApiForpost


class V1WalletsWalletIdAddresses(
    ApiForget,
    ApiForpost,
):
    pass
