# coding: utf-8

# flake8: noqa

"""
    Generated by: https://openapi-generator.tech
"""

__version__ = "0.1.0-beta.12"

# import ApiClient
from circle.api_client import ApiClient

# import Configuration
from circle.configuration import Configuration

# import exceptions
from circle.exceptions import OpenApiException
from circle.exceptions import ApiAttributeError
from circle.exceptions import ApiTypeError
from circle.exceptions import ApiValueError
from circle.exceptions import ApiKeyError
from circle.exceptions import ApiException

from enum import Enum

# Global config variables and constants
class Environment(Enum):
    SANDBOX_BASE_URL = "https://api-sandbox.circle.com"
    PRODUCTION_BASE_URL = "https://api.circle.com"

api_key = "<replace-me-with-your-api-key>"
base_url = Environment.SANDBOX_BASE_URL
