# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_notifications_subscriptions.post import CreateSubscription
from circle.paths.v1_notifications_subscriptions_id.delete import DeleteSubscription
from circle.paths.v1_notifications_subscriptions.get import ListSubscriptions


class SubscriptionsApi(
    CreateSubscription,
    DeleteSubscription,
    ListSubscriptions,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
