# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_balances.get import ListBalances
from circle.paths.v1_business_account_balances.get import ListBusinessBalances


class BalancesApi(
    ListBalances,
    ListBusinessBalances,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
