# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class WireCreationRequestUs(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Relevant fields for U.S. bank accounts.
    """


    class MetaOapg:
        required = {
            "routingNumber",
            "billingDetails",
            "idempotencyKey",
            "accountNumber",
            "bankAddress",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
            
            
            class accountNumber(
                schemas.StrSchema
            ):
                pass
            routingNumber = schemas.StrSchema
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
        
            @staticmethod
            def bankAddress() -> typing.Type['BankAddress']:
                return BankAddress
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "accountNumber": accountNumber,
                "routingNumber": routingNumber,
                "billingDetails": billingDetails,
                "bankAddress": bankAddress,
            }
    
    routingNumber: MetaOapg.properties.routingNumber
    billingDetails: 'BillingDetails'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    accountNumber: MetaOapg.properties.accountNumber
    bankAddress: 'BankAddress'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["accountNumber"]) -> MetaOapg.properties.accountNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["routingNumber"]) -> MetaOapg.properties.routingNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bankAddress"]) -> 'BankAddress': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "accountNumber", "routingNumber", "billingDetails", "bankAddress", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["accountNumber"]) -> MetaOapg.properties.accountNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["routingNumber"]) -> MetaOapg.properties.routingNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bankAddress"]) -> 'BankAddress': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "accountNumber", "routingNumber", "billingDetails", "bankAddress", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        routingNumber: typing.Union[MetaOapg.properties.routingNumber, str, ],
        billingDetails: 'BillingDetails',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        accountNumber: typing.Union[MetaOapg.properties.accountNumber, str, ],
        bankAddress: 'BankAddress',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WireCreationRequestUs':
        return super().__new__(
            cls,
            *_args,
            routingNumber=routingNumber,
            billingDetails=billingDetails,
            idempotencyKey=idempotencyKey,
            accountNumber=accountNumber,
            bankAddress=bankAddress,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.bank_address import BankAddress
from circle.model.billing_details import BillingDetails
