# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_wallets_addresses_deposit.post import CreateBusinessDepositAddress
from circle.paths.v1_business_account_wallets_addresses_recipient.post import CreateBusinessRecipientAddress
from circle.paths.v1_business_account_wallets_addresses_deposit.get import GetBusinessDepositAddress
from circle.paths.v1_business_account_wallets_addresses_recipient.get import ListBusinessRecipientAddresses


class AddressesApi(
    CreateBusinessDepositAddress,
    CreateBusinessRecipientAddress,
    GetBusinessDepositAddress,
    ListBusinessRecipientAddresses,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
