from circle.paths.v1_business_account_wallets_addresses_deposit.get import ApiForget
from circle.paths.v1_business_account_wallets_addresses_deposit.post import ApiForpost


class V1BusinessAccountWalletsAddressesDeposit(
    ApiForget,
    ApiForpost,
):
    pass
