# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payments_crypto.post import CreateCryptoPayment
from circle.paths.v1_payments_presign.get import Presign


class PullCryptoPaymentsApi(
    CreateCryptoPayment,
    Presign,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
