# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ChargebackStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated status of the chargeback. `active` means you’ve received a dispute and you need to submit evidence if you want to defend against it. 'resolved' means the disputed payment had been refunded previously. Your account has not been debited. `pending` means we have acknowledged your evidence and forwarded it to the card issuer. `won` means you have won the dispute and your account has been credited. `lost` means the issuing bank has rejected your evidence and you have lost the dispute. There are no further financial implications. `canceled` means the issuing bank has canceled the dispute and your account has been credited. `closed` means the time to respond to this dispute has run out. No evidence can be submitted at this point.
    """


    class MetaOapg:
        enum_value_to_name = {
            "active": "ACTIVE",
            "resolved": "RESOLVED",
            "pending": "PENDING",
            "won": "WON",
            "lost": "LOST",
            "canceled": "CANCELED",
            "closed": "CLOSED",
        }
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("active")
    
    @schemas.classproperty
    def RESOLVED(cls):
        return cls("resolved")
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")
    
    @schemas.classproperty
    def WON(cls):
        return cls("won")
    
    @schemas.classproperty
    def LOST(cls):
        return cls("lost")
    
    @schemas.classproperty
    def CANCELED(cls):
        return cls("canceled")
    
    @schemas.classproperty
    def CLOSED(cls):
        return cls("closed")
