# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301
import html

NAME = "circle-sdk"
VERSION = "0.1.0-beta.12"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

with open('README.md') as f:
    readme_content = f.read()

setup(
    name=NAME,
    version=VERSION,
    author="Circle SDK Developers",
    author_email="sdk-developers+pypi@circle.com",
    url="",
    keywords=["circle", "circle.com", "usdc", "euroc", "stablecoins"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    description="Python SDK for Circle APIs",
    long_description_content_type="text/markdown",
    long_description=readme_content
)
