# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CvvResults(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated status of the check. `not_requested` indicates check was not made. `pass` indicates value is correct. `fail` indicates value is incorrect. `unavailable` indicates card issuer did not do the provided check. `pending` indicates check is pending/processing.
    """
    
    @schemas.classproperty
    def NOT_REQUESTED(cls):
        return cls("not_requested")
    
    @schemas.classproperty
    def PASS(cls):
        return cls("pass")
    
    @schemas.classproperty
    def FAIL(cls):
        return cls("fail")
    
    @schemas.classproperty
    def UNAVAILABLE(cls):
        return cls("unavailable")
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")
